# @push.rocks/smartpdf
Create PDFs on the fly

## Install
To install `@push.rocks/smartpdf`, use the following command with npm:

```bash
npm install @push.rocks/smartpdf --save
```

Or with yarn:

```bash
yarn add @push.rocks/smartpdf
```

## Usage
This documentation will guide you through using `@push.rocks/smartpdf` to create PDFs in various ways, such as from HTML strings or full web pages, and provides examples on how to merge multiple PDFs into one. Remember, all examples provided here use ESM syntax and TypeScript.

### Getting Started
First, ensure you have the package installed and you can import it into your TypeScript project:

```typescript
import { SmartPdf, IPdf } from '@push.rocks/smartpdf';
```

### Creating a PDF from an HTML String
To create a PDF from a simple HTML string, you’ll need to instantiate `SmartPdf` and call `getA4PdfResultForHtmlString`.

```typescript
async function createPdfFromHtml() {
  const smartPdf = await SmartPdf.create();
  await smartPdf.start();
  const htmlString = `<h1>Hello World</h1>`;
  const pdf: IPdf = await smartPdf.getA4PdfResultForHtmlString(htmlString);
  console.log(pdf.buffer); // This is your PDF buffer
  await smartPdf.stop();
}
createPdfFromHtml();
```

### Generating a PDF from a Website
You may want to capture a full webpage as a PDF. `SmartPdf` provides two methods to accomplish this. One captures the viewable area as an A4 pdf, and the other captures the entire webpage.

#### A4 PDF from a Website

```typescript
async function createA4PdfFromWebsite() {
  const smartPdf = await SmartPdf.create();
  await smartPdf.start();
  const pdf: IPdf = await smartPdf.getPdfResultForWebsite('https://example.com');
  console.log(pdf.buffer); // PDF buffer of the webpage
  await smartPdf.stop();
}
createA4PdfFromWebsite();
```

#### Full Webpage as a Single PDF

```typescript
async function createFullPdfFromWebsite() {
  const smartPdf = await SmartPdf.create();
  await smartPdf.start();
  const pdf: IPdf = await smartPdf.getFullWebsiteAsSinglePdf('https://example.com');
  console.log(pdf.buffer); // PDF buffer with the full webpage
  await smartPdf.stop();
}
createFullPdfFromWebsite();
```

### Merging Multiple PDFs
If you have multiple PDF objects (`IPdf`) that you wish to merge into a single PDF file, you can use the `mergePdfs` method.

```typescript
async function mergePdfs() {
  const smartPdf = await SmartPdf.create();
  // Assume pdf1 and pdf2 are objects of type IPdf that you want to merge
  const mergedPdf: IPdf = await smartPdf.mergePdfs([pdf1, pdf2]);
  console.log(mergedPdf.buffer); // Buffer of the merged PDF
}
mergePdfs();
```

### Reading PDF from Disk and Extracting Text
To read a PDF from the disk and extract its text content:

```typescript
async function readAndExtractFromPdf() {
  const smartPdf = await SmartPdf.create();
  const pdf: IPdf = await smartPdf.readFileToPdfObject('/path/to/your/pdf/file.pdf');
  const extractedText = await smartPdf.extractTextFromPdfBuffer(pdf.buffer);
  console.log(extractedText);  // Extracted text from the PDF
}
readAndExtractFromPdf();
```

This guide provides a comprehensive overview of generating PDFs using `@push.rocks/smartpdf`. Remember to start and stop your `SmartPdf` instance to properly initialize and clean up resources, especially when working with server-side rendering or capturing web pages.

## License and Legal Information

This repository contains open-source code that is licensed under the MIT License. A copy of the MIT License can be found in the [license](license) file within this repository. 

**Please note:** The MIT License does not grant permission to use the trade names, trademarks, service marks, or product names of the project, except as required for reasonable and customary use in describing the origin of the work and reproducing the content of the NOTICE file.

### Trademarks

This project is owned and maintained by Task Venture Capital GmbH. The names and logos associated with Task Venture Capital GmbH and any related products or services are trademarks of Task Venture Capital GmbH and are not included within the scope of the MIT license granted herein. Use of these trademarks must comply with Task Venture Capital GmbH's Trademark Guidelines, and any usage must be approved in writing by Task Venture Capital GmbH.

### Company Information

Task Venture Capital GmbH  
Registered at District court Bremen HRB 35230 HB, Germany

For any legal inquiries or if you require further information, please contact us via email at hello@task.vc.

By using this repository, you acknowledge that you have read this section, agree to comply with its terms, and understand that the licensing of the code does not imply endorsement by Task Venture Capital GmbH of any derivative works.
